@@ -15,7 +15,6 @@ use File::Temp qw(tempdir tempfile);
 use Digest::SHA qw(sha1_hex);
 use Archive::Extract;
 use Config;
-use ExtUtils::Liblist;
 use Text::Patch;
 use IPC::Run3;
 
@@ -35,7 +34,7 @@ sub ACTION_install {
 sub ACTION_code {
   my $self = shift;
 
-  unless (-e 'build_done') {
+  if ( ! -e 'build_done' ) {
     my $inst = $self->notes('already_installed_lib');
     if (defined $inst) {
       $self->config_data('config', { LIBS   => $inst->{lflags},
@@ -113,8 +112,7 @@ sub ACTION_code {
                                    });
     }
     # mark sucessfully finished build
-    local @ARGV = ('build_done');
-    ExtUtils::Command::touch();
+    $self->touchfile('build_done');
   }
   $self->SUPER::ACTION_code;
 }
@@ -180,7 +178,7 @@ sub check_installed_lib {
   
   #xxxTODO
   #we not only need to detect the presence we also need to exactly know what libs are there - necessary for havelib() function
-  print STDERR "\nNOTICE:\nDetection of preinstalled iup+cd+im is disabled since v0.115!\nPlease contact the module author if you are missing this feature.\n";
+  print STDERR "\nNOTICE:\nDetection of preinstalled iup+cd+im is disabled since v0.115!\nPlease contact the module author if you are missing this feature.\n\n";
   return 0;
   
   my $idir = $ENV{IUP_DIR} || '';
@@ -433,4 +431,14 @@ sub sort_libs {
   return @sorted;
 }
 
+sub touchfile {
+  my $self = shift;
+  my $t    = time;
+  foreach my $file (@_) {
+    open(FILE,">>$file") || die "Cannot write $file:$!";
+    close(FILE);
+    utime($t,$t,$file);
+  }
+}
+
 1;
